@@ -24,10 +24,10 @@ pub enum Family {
     Avatar = 23,
     Party = 24,
     Refresh = 25,
-    NPC = 26,
-    PlayerAutoRefresh = 27,
-    NPCAutoRefresh = 28,
-    Appear = 29,
+    Npc = 26,
+    CharacterMapInfo = 27,
+    NpcMapInfo = 28,
+    MapInfo = 29,
     Paperdoll = 30,
     Effect = 31,
     Trade = 32,
